@@ -1,9 +1,13 @@
 from torchsilk.modules.buffers import NamedBuffers as NamedBuffers
+from torchsilk.modules.functorch_ import make_functional as make_functional
+from torchsilk.modules.functorch_ import (
+    make_functional_with_buffers as make_functional_with_buffers,
+)
 from torchsilk.modules.module import Module as Module
 from torchsilk.modules.module_state import ModuleState as ModuleState
 from torchsilk.modules.train_state import LossFunction as LossFunction
 from torchsilk.modules.train_state import TrainState as TrainState
 from torchsilk.modules.type_defs import FunctionalModule as FunctionalModule
 from torchsilk.modules.type_defs import (
-    FunctionalModuleWithoutBuffers as FunctionalModuleWithoutBuffers,
+    FunctionalModuleWithBuffers as FunctionalModuleWithBuffers,
 )
