@@ -13,7 +13,7 @@ from rich.table import Table
 from torchsilk import type_defs as tdf
 from torchsilk.modules.buffers import NamedBuffers
 from torchsilk.modules.module_state import ModuleState
-from torchsilk.modules.type_defs import FunctionalModule, FunctionalModuleWithoutBuffers
+from torchsilk.modules.type_defs import FunctionalModule, FunctionalModuleWithBuffers
 
 
 def json_to_yaml(x: str) -> str:
@@ -159,7 +159,7 @@ class Module(t.Generic[tdf.PydanticModel, tdf.P, tdf.R_co]):
     @property
     def module(
         self,
-    ) -> FunctionalModuleWithoutBuffers[tdf.P, tdf.R_co] | FunctionalModule[
+    ) -> FunctionalModule[tdf.P, tdf.R_co] | FunctionalModuleWithBuffers[
         tdf.P, tdf.R_co
     ]:
         return self._module_state.module
