@@ -8,7 +8,7 @@ import typing_extensions as te
 
 from torchsilk import type_defs as tdf
 from torchsilk.modules.buffers import NamedBuffers
-from torchsilk.modules.type_defs import FunctionalModule, FunctionalModuleWithoutBuffers
+from torchsilk.modules.type_defs import FunctionalModule, FunctionalModuleWithBuffers
 
 
 class _ModuleStateWithoutBuffers(t.Generic[tdf.P, tdf.R_co]):
@@ -35,7 +35,7 @@ class _ModuleStateWithoutBuffers(t.Generic[tdf.P, tdf.R_co]):
 
     def __init__(
         self,
-        module: FunctionalModuleWithoutBuffers[tdf.P, tdf.R_co],
+        module: FunctionalModule[tdf.P, tdf.R_co],
         parameters: tuple[torch.nn.Parameter, ...],
     ) -> None:
         """NOTE: Not intended to be called directly. Use `from_torch_module` instead."""
@@ -100,12 +100,10 @@ class _ModuleStateWithoutBuffers(t.Generic[tdf.P, tdf.R_co]):
         func, parameters = ft.make_functional(
             torch_module, disable_autograd_tracking=True
         )
-        return cls(
-            t.cast(FunctionalModuleWithoutBuffers[tdf.P, tdf.R_co], func), parameters
-        )
+        return cls(t.cast(FunctionalModule[tdf.P, tdf.R_co], func), parameters)
 
     @property
-    def module(self) -> FunctionalModuleWithoutBuffers[tdf.P, tdf.R_co]:
+    def module(self) -> FunctionalModule[tdf.P, tdf.R_co]:
         """Return the underlying stateless module."""
         return self._module
 
@@ -208,7 +206,7 @@ class _ModuleStateWithBuffers(t.Generic[tdf.P, tdf.R_co]):
 
     def __init__(
         self,
-        module: FunctionalModule[tdf.P, tdf.R_co],
+        module: FunctionalModuleWithBuffers[tdf.P, tdf.R_co],
         parameters: tuple[torch.nn.Parameter, ...],
         buffers: tuple[torch.Tensor, ...],
         named_buffers: NamedBuffers,
@@ -250,14 +248,14 @@ class _ModuleStateWithBuffers(t.Generic[tdf.P, tdf.R_co]):
             torch_module, disable_autograd_tracking=True
         )
         return cls(
-            module=t.cast(FunctionalModule[tdf.P, tdf.R_co], func),
+            module=t.cast(FunctionalModuleWithBuffers[tdf.P, tdf.R_co], func),
             parameters=parameters,
             buffers=buffers,
             named_buffers=named_buffers.evolve_from_values(buffers),
         )
 
     @property
-    def module(self) -> FunctionalModule[tdf.P, tdf.R_co]:
+    def module(self) -> FunctionalModuleWithBuffers[tdf.P, tdf.R_co]:
         return self._module
 
     @property
@@ -462,7 +460,7 @@ class ModuleState(t.Generic[tdf.P, tdf.R_co]):
     @property
     def module(
         self,
-    ) -> FunctionalModuleWithoutBuffers[tdf.P, tdf.R_co] | FunctionalModule[
+    ) -> FunctionalModule[tdf.P, tdf.R_co] | FunctionalModuleWithBuffers[
         tdf.P, tdf.R_co
     ]:
         return self._module_state.module
